@@ -1,9 +1,48 @@
 package Chart::Clicker::Data::Range;
 use strict;
+use warnings;
 
 use base 'Class::Accessor';
 __PACKAGE__->mk_accessors(qw(lower upper));
 
+sub span {
+    my $self = shift();
+
+    return $self->upper() - $self->lower();
+}
+
+sub combine {
+    my $self = shift();
+    my $range = shift();
+
+    if(!defined($self->lower()) || ($range->lower() < $self->lower())) {
+        $self->lower($range->lower());
+    }
+
+    if(!defined($self->upper()) || ($range->upper() > $self->upper())) {
+        $self->upper($range->upper());
+    }
+
+    return 1;
+}
+
+sub divvy {
+    my $self = shift();
+    my $n = shift();
+
+    my $per = $self->span() / $n;
+
+    my @vals;
+    for(1..($n - 1)) {
+        push(@vals, $_ * $per);
+    }
+
+    return \@vals;
+}
+
+1;
+__END__
+
 =head1 NAME
 
 Chart::Clicker::Data::Range
@@ -43,32 +82,11 @@ Set/Get the upper bound for this Range
 
 Returns the span of this range, or UPPER - LOWER.
 
-=cut
-sub span {
-    my $self = shift();
-
-    return $self->upper() - $self->lower();
-}
-
 =item combine
 
 Combine this range with the specified so that this range encompasses the
 values specified.
 
-=cut
-sub combine {
-    my $self = shift();
-    my $range = shift();
-
-    if(!defined($self->lower()) or ($range->lower() < $self->lower())) {
-        $self->lower($range->lower());
-    }
-
-    if(!defined($self->upper()) or ($range->upper() > $self->upper())) {
-        $self->upper($range->upper());
-    }
-}
-
 =item divvy
 
   my $values = $range->divvy(5);
@@ -76,28 +94,13 @@ sub combine {
 Returns an arrayref of $N - 1 values equally spaced in the range so that
 it may be divided into $N pieces.
 
-=cut
-sub divvy {
-    my $self = shift();
-    my $n = shift();
-
-    my $per = $self->span() / $n;
-
-    my @vals;
-    for(my $i = 1; $i < $n; $i++) {
-        push(@vals, $i * $per);
-    }
-
-    return \@vals;
-}
-
 =back
 
 =head1 AUTHOR
 
 Cory 'G' Watson <jheephat@cpan.org>
 
-=head1 SEE ALSO
+=head1 LICENSE
 
-=cut
-1;
+You can redistribute and/or modify this code under the same terms as Perl
+itself.
