@@ -1,5 +1,6 @@
 package Chart::Clicker::Data::Series;
 use strict;
+use warnings;
 
 use base 'Class::Accessor';
 __PACKAGE__->mk_accessors(
@@ -8,6 +9,67 @@ __PACKAGE__->mk_accessors(
 
 use Chart::Clicker::Data::Range;
 
+sub new {
+    my $proto = shift();
+    my $class = ref($proto) || $proto;
+    my $self = {};
+
+    $self->{'OPTIONS'} = {};
+
+    bless($self, $class);
+    return $self;
+}
+
+sub prepare {
+    my $self = shift();
+
+    my @values = @{ $self->values() };
+    my @keys = @{ $self->keys() };
+
+    $self->key_count(scalar(@keys));
+    $self->value_count(scalar(@values));
+
+    if($self->key_count() != $self->value_count()) {
+        die('Series key/value counts dont match.');
+    }
+
+    my ($long, $max, $min);
+    $long = 0;
+    $max = $values[0];
+    $min = $values[0];
+    my $count = 0;
+    foreach my $key (@keys) {
+
+        my $val = $values[$count];
+
+        # Length!
+        my $l = length($key);
+        if($l > $long) {
+            $long = $l;
+        }
+
+        # Max
+        if($val > $max) {
+            $max = $val;
+        }
+
+        # Min
+        if($val < $min) {
+            $min = $val;
+        }
+        $count++;
+    }
+    $self->max_key_length($long);
+    $self->range(
+        new Chart::Clicker::Data::Range({ lower => $min, upper => $max })
+    );
+
+    return 1;
+}
+
+1;
+__END__
+
 =head1 NAME
 
 Chart::Clicker::Data::Series
@@ -38,18 +100,6 @@ Chart::Clicker::Data::Series is the core class
 
 Creates a new, empty Series
 
-=cut
-sub new {
-    my $proto = shift();
-    my $class = ref($proto) || $proto;
-    my $self = {};
-
-    $self->{'OPTIONS'} = {};
-
-    bless($self, $class);
-    return $self;
-}
-
 =item name
 
 Set/Get the name for this Series
@@ -67,50 +117,6 @@ Set/Get the values for this series.
 Prepare this series.  Performs various checks and calculates
 various things.
 
-=cut
-sub prepare {
-    my $self = shift();
-
-    my @values = @{ $self->values() };
-    my @keys = @{ $self->keys() };
-
-    $self->key_count(scalar(@keys));
-    $self->value_count(scalar(@values));
-
-    if($self->key_count() != $self->value_count()) {
-        die("Series key/value counts don't match.");
-    }
-
-    my ($long, $max, $min);
-    $long = 0;
-    $max = $values[0];
-    $min = $values[0];
-    my $count = 0;
-    foreach my $key (@keys) {
-
-        my $val = $values[$count];
-
-        # Length!
-        my $l = length($key);
-        if($l > $long) {
-            $long = $l;
-        }
-
-        # Max
-        if($val > $max) {
-            $max = $val;
-        }
-
-        # Min
-        if($val < $min) {
-            $min = $val;
-        }
-        $count++;
-    }
-    $self->max_key_length($long);
-    $self->range(new Chart::Clicker::Data::Range({ lower => $min, upper => $max }));
-}
-
 =item range
 
 Returns the range for this series.
@@ -135,7 +141,7 @@ after the series has been prepared.
 
 Cory 'G' Watson <jheephat@cpan.org>
 
-=head1 SEE ALSO
+=head1 LICENSE
 
-=cut
-1;
+You can redistribute and/or modify this code under the same terms as Perl
+itself.
